Level

Struct Level 

pub struct Level {
Show 28 fields pub name: String, pub x: i32, pub y: i32, pub width: i32, pub height: i32, pub music_layer_1: bool, pub music_layer_2: bool, pub music_layer_3: bool, pub music_layer_4: bool, pub music_progress: String, pub whisper: bool, pub underwater: bool, pub c: i32, pub alt_music: String, pub space: bool, pub wind_pattern: String, pub disable_down_transition: bool, pub dark: bool, pub fgdecals: FGDecals, pub bgdecals: BGDecals, pub fgtiles: FGTiles, pub bgtiles: BGTiles, pub solids: Solids, pub bg: BGSolids, pub entities: Entities, pub triggers: Triggers, pub objtiles: Option<ObjTiles>, pub invalid: Vec<BinEl>,
}
A room in a Map. Only confusingly named fields are documented.

Fields

name: Stringx: i32y: i32width: i32height: i32music_layer_1: boolmusic_layer_2: boolmusic_layer_3: boolmusic_layer_4: boolmusic_progress: Stringwhisper: boolunderwater: boolc: i32

Unclear what this does.

alt_music: String

Unclear what this does, though I believe that it is the default music used by Music triggers.

space: bool

Alternate gravity. Behavior may be unstable in different game versions.

wind_pattern: Stringdisable_down_transition: booldark: bool

Affects lighting shaders.

fgdecals: FGDecalsbgdecals: BGDecalsfgtiles: FGTilesbgtiles: BGTilessolids: Solidsbg: BGSolidsentities: Entitiestriggers: Triggersobjtiles: Option<ObjTiles>

Optional, as some serializers (such as older versions of Maple) don’t include these.

invalid: Vec<BinEl>

All children that failed to parse.